pidproxyd
=========

.. image:: https://img.shields.io/pypi/v/pidproxyd.svg
    :target: https://pypi.python.org/pypi/pidproxyd
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/ajpen/pidproxyd.png
   :target: https://travis-ci.org/ajpen/pidproxyd
   :alt: Latest Travis CI build status

A pidproxy for daemonized processes.

Usage
-----

`pidproxyd.py <pidfile name> <command> [<cmdarg1> ...]`

There is an included Dockerfile for running the example.

Installation
------------

`pip install pidproxyd`


Compatibility
-------------

pidproxyd is compatible with python 2.7 and python 3

Licence
-------

MIT

Authors
-------

`pidproxyd` was written by `Anfernee Jervis <anferneejervis@gmail.com>`_.
The `daemon.py` script is from https://gist.github.com/marazmiki/3618191